@@ -17,9 +17,10 @@ function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) r
 import PropTypes from 'prop-types';
 import React from 'react';
 import classNames from 'classnames';
+import { Text } from '../Text';
 import { useFeatureFlag } from '../FeatureFlags';
-import { settings } from 'carbon-components';
-var prefix = settings.prefix;
+import deprecate from '../../prop-types/deprecate';
+import { usePrefix } from '../../internal/usePrefix';
 var Checkbox = /*#__PURE__*/React.forwardRef(function Checkbox(_ref, _ref2) {
   var className = _ref.className,
       id = _ref.id,
@@ -32,10 +33,11 @@ var Checkbox = /*#__PURE__*/React.forwardRef(function Checkbox(_ref, _ref2) {
       title = _ref$title === void 0 ? '' : _ref$title,
       other = _objectWithoutProperties(_ref, _excluded);
 
-  var labelClasses = classNames("".concat(prefix, "--checkbox-label"), className);
-  var innerLabelClasses = classNames("".concat(prefix, "--checkbox-label-text"), _defineProperty({}, "".concat(prefix, "--visually-hidden"), hideLabel));
-  var wrapperClasses = classNames("".concat(prefix, "--form-item"), "".concat(prefix, "--checkbox-wrapper"), wrapperClassName);
   var enabled = useFeatureFlag('enable-v11-release');
+  var prefix = usePrefix();
+  var labelClasses = classNames("".concat(prefix, "--checkbox-label"), [enabled ? null : className]);
+  var innerLabelClasses = classNames("".concat(prefix, "--checkbox-label-text"), _defineProperty({}, "".concat(prefix, "--visually-hidden"), hideLabel));
+  var wrapperClasses = classNames("".concat(prefix, "--form-item"), "".concat(prefix, "--checkbox-wrapper"), [enabled ? className : wrapperClassName]);
   return /*#__PURE__*/React.createElement("div", {
     className: wrapperClasses
   }, /*#__PURE__*/React.createElement("input", _extends({}, other, {
@@ -67,7 +69,7 @@ var Checkbox = /*#__PURE__*/React.forwardRef(function Checkbox(_ref, _ref2) {
     htmlFor: id,
     className: labelClasses,
     title: title || null
-  }, /*#__PURE__*/React.createElement("span", {
+  }, /*#__PURE__*/React.createElement(Text, {
     className: innerLabelClasses
   }, labelText)));
 });
@@ -127,7 +129,7 @@ Checkbox.propTypes = {
   /**
    * The CSS class name to be placed on the wrapping element
    */
-  wrapperClassName: PropTypes.string
+  wrapperClassName: deprecate(PropTypes.string, "\nThe prop `wrapperClassName` for Checkbox will be deprecated in V11 in favor of `className`. `className` will then be placed on the outer wrapper.")
 };
 Checkbox.defaultProps = {
   onChange: function onChange() {},
