@@ -34,7 +34,7 @@ import cx from 'classnames';
 import Downshift from 'downshift';
 import PropTypes from 'prop-types';
 import React, { useEffect, useState, useRef } from 'react';
-import { settings } from 'carbon-components';
+import { Text } from '../Text';
 import { Checkmark16, WarningAltFilled16, WarningFilled16 } from '@carbon/icons-react';
 import ListBox, { PropTypes as ListBoxPropTypes } from '../ListBox';
 import { ListBoxTrigger, ListBoxSelection } from '../ListBox/next';
@@ -42,7 +42,8 @@ import { match, keys } from '../../internal/keyboard';
 import setupGetInstanceId from '../../tools/setupGetInstanceId';
 import { mapDownshiftProps } from '../../tools/createPropAdapter';
 import mergeRefs from '../../tools/mergeRefs';
-var prefix = settings.prefix;
+import { useFeatureFlag } from '../FeatureFlags';
+import { usePrefix } from '../../internal/usePrefix';
 
 var defaultItemToString = function defaultItemToString(item) {
   if (typeof item === 'string') {
@@ -127,6 +128,7 @@ var ComboBox = /*#__PURE__*/React.forwardRef(function (props, ref) {
       warnText = props.warnText,
       rest = _objectWithoutProperties(props, _excluded);
 
+  var prefix = usePrefix();
   var textInput = useRef();
   var comboBoxInstanceId = getInstanceId();
 
@@ -225,12 +227,13 @@ var ComboBox = /*#__PURE__*/React.forwardRef(function (props, ref) {
     };
   };
 
+  var enabled = useFeatureFlag('enable-v11-release');
   var showWarning = !invalid && warn;
-  var className = cx("".concat(prefix, "--combo-box"), containerClassName, (_cx = {}, _defineProperty(_cx, "".concat(prefix, "--list-box--up"), direction === 'top'), _defineProperty(_cx, "".concat(prefix, "--combo-box--warning"), showWarning), _cx));
+  var className = cx("".concat(prefix, "--combo-box"), [enabled ? null : containerClassName], (_cx = {}, _defineProperty(_cx, "".concat(prefix, "--list-box--up"), direction === 'top'), _defineProperty(_cx, "".concat(prefix, "--combo-box--warning"), showWarning), _cx));
   var titleClasses = cx("".concat(prefix, "--label"), _defineProperty({}, "".concat(prefix, "--label--disabled"), disabled));
   var comboBoxHelperId = !helperText ? undefined : "combobox-helper-text-".concat(comboBoxInstanceId);
   var helperClasses = cx("".concat(prefix, "--form__helper-text"), _defineProperty({}, "".concat(prefix, "--form__helper-text--disabled"), disabled));
-  var wrapperClasses = cx("".concat(prefix, "--list-box__wrapper"));
+  var wrapperClasses = cx("".concat(prefix, "--list-box__wrapper"), [enabled ? containerClassName : null]);
   var inputClasses = cx("".concat(prefix, "--text-input"), _defineProperty({}, "".concat(prefix, "--text-input--empty"), !inputValue)); // needs to be Capitalized for react to render it correctly
 
   var ItemToElement = itemToElement;
@@ -244,6 +247,8 @@ var ComboBox = /*#__PURE__*/React.forwardRef(function (props, ref) {
     inputId: id,
     selectedItem: selectedItem
   }), function (_ref4) {
+    var _textInput$current;
+
     var getInputProps = _ref4.getInputProps,
         getItemProps = _ref4.getItemProps,
         getLabelProps = _ref4.getLabelProps,
@@ -269,11 +274,13 @@ var ComboBox = /*#__PURE__*/React.forwardRef(function (props, ref) {
       // https://github.com/downshift-js/downshift/blob/v5.2.1/src/downshift.js#L1051-L1065
       //
       // As a result, it will reset the state of the component and so we
-      // stop the event from propagating to prevent this. This allows the
-      // toggleMenu behavior for the toggleButton to correctly open and
+      // stop the event from propagating to prevent this if the menu is already open.
+      // This allows the toggleMenu behavior for the toggleButton to correctly open and
       // close the menu.
       onMouseUp: function onMouseUp(event) {
-        event.stopPropagation();
+        if (isOpen) {
+          event.stopPropagation();
+        }
       }
     });
     var inputProps = getInputProps({
@@ -296,7 +303,8 @@ var ComboBox = /*#__PURE__*/React.forwardRef(function (props, ref) {
     });
     return /*#__PURE__*/React.createElement("div", {
       className: wrapperClasses
-    }, titleText && /*#__PURE__*/React.createElement("label", _extends({
+    }, titleText && /*#__PURE__*/React.createElement(Text, _extends({
+      as: "label",
       className: titleClasses
     }, labelProps), titleText), /*#__PURE__*/React.createElement(ListBox, {
       className: className,
@@ -319,7 +327,8 @@ var ComboBox = /*#__PURE__*/React.forwardRef(function (props, ref) {
       "aria-autocomplete": "list",
       "aria-expanded": rootProps['aria-expanded'],
       "aria-haspopup": "listbox",
-      "aria-controls": inputProps['aria-controls']
+      "aria-controls": inputProps['aria-controls'],
+      title: textInput === null || textInput === void 0 ? void 0 : (_textInput$current = textInput.current) === null || _textInput$current === void 0 ? void 0 : _textInput$current.value
     }, inputProps, rest, {
       ref: mergeRefs(textInput, ref)
     })), invalid && /*#__PURE__*/React.createElement(WarningFilled16, {
@@ -354,12 +363,14 @@ var ComboBox = /*#__PURE__*/React.forwardRef(function (props, ref) {
       }, item)) : itemToString(item), selectedItem === item && /*#__PURE__*/React.createElement(Checkmark16, {
         className: "".concat(prefix, "--list-box__menu-item__selected-icon")
       }));
-    }) : null)), helperText && !invalid && !warn && /*#__PURE__*/React.createElement("div", {
+    }) : null)), helperText && !invalid && !warn && /*#__PURE__*/React.createElement(Text, {
+      as: "div",
       id: comboBoxHelperId,
       className: helperClasses
     }, helperText));
   });
 });
+ComboBox.displayName = 'ComboBox';
 ComboBox.propTypes = {
   /**
    * 'aria-label' of the ListBox component.
@@ -401,7 +412,7 @@ ComboBox.propTypes = {
    * Allow users to pass in an arbitrary item or a string (in case their items are an array of strings)
    * from their collection that are pre-selected
    */
-  initialSelectedItem: PropTypes.oneOfType([PropTypes.object, PropTypes.string]),
+  initialSelectedItem: PropTypes.oneOfType([PropTypes.object, PropTypes.string, PropTypes.number]),
 
   /**
    * Specify if the currently selected value is invalid.
@@ -466,7 +477,7 @@ ComboBox.propTypes = {
   /**
    * For full control of the selection
    */
-  selectedItem: PropTypes.oneOfType([PropTypes.object, PropTypes.string]),
+  selectedItem: PropTypes.oneOfType([PropTypes.object, PropTypes.string, PropTypes.number]),
 
   /**
    * Specify your own filtering logic by passing in a `shouldFilterItem`
