@@ -1,3 +1,5 @@
+var _excluded = ["className", "children", "shouldShowBatchActions", "totalSelected", "onCancel", "translateWithId"];
+
 function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }
 
 function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }
@@ -42,7 +44,7 @@ var TableBatchActions = function TableBatchActions(_ref) {
       totalSelected = _ref.totalSelected,
       onCancel = _ref.onCancel,
       t = _ref.translateWithId,
-      rest = _objectWithoutProperties(_ref, ["className", "children", "shouldShowBatchActions", "totalSelected", "onCancel", "translateWithId"]);
+      rest = _objectWithoutProperties(_ref, _excluded);
 
   var batchActionsClasses = cx((_cx = {}, _defineProperty(_cx, "".concat(prefix, "--batch-actions"), true), _defineProperty(_cx, "".concat(prefix, "--batch-actions--active"), shouldShowBatchActions), _cx), className);
   return /*#__PURE__*/React.createElement("div", _extends({}, rest, {
@@ -70,7 +72,7 @@ TableBatchActions.propTypes = {
 
   /**
    * Hook required to listen for when the user initiates a cancel request
-   * through this comopnent
+   * through this component
    */
   onCancel: PropTypes.func.isRequired,
 
@@ -88,7 +90,7 @@ TableBatchActions.propTypes = {
 
   /**
    * Supply a method to translate internal strings with your i18n tool of
-   * choice. Translation keys are avabile on the `translationKeys` field for
+   * choice. Translation keys are available on the `translationKeys` field for
    * this component.
    */
   translateWithId: PropTypes.func
