@@ -1,3 +1,5 @@
+var _excluded = ["className", "children", "colSpan"];
+
 function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }
 
 function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = _objectWithoutPropertiesLoose(source, excluded); var key, i; if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }
@@ -21,7 +23,7 @@ var TableExpandedRow = function TableExpandedRow(_ref) {
   var customClassName = _ref.className,
       children = _ref.children,
       colSpan = _ref.colSpan,
-      rest = _objectWithoutProperties(_ref, ["className", "children", "colSpan"]);
+      rest = _objectWithoutProperties(_ref, _excluded);
 
   var rowRef = useRef(null);
   var className = cx("".concat(prefix, "--expandable-row"), customClassName);
