@@ -122,7 +122,7 @@ describe('Dropdown', function () {
   it('should let the user select an option by clicking on the option node', function () {
     var wrapper = mount( /*#__PURE__*/React.createElement(Dropdown, mockProps));
     openMenu(wrapper);
-    wrapper.find('ForwardRef(ListBoxMenuItem)').at(0).simulate('click');
+    wrapper.find('ListBoxMenuItem').at(0).simulate('click');
     expect(mockProps.onChange).toHaveBeenCalledTimes(1);
     expect(mockProps.onChange).toHaveBeenCalledWith({
       selectedItem: mockProps.items[0]
@@ -130,7 +130,7 @@ describe('Dropdown', function () {
     assertMenuClosed(wrapper);
     mockProps.onChange.mockClear();
     openMenu(wrapper);
-    wrapper.find('ForwardRef(ListBoxMenuItem)').at(1).simulate('click');
+    wrapper.find('ListBoxMenuItem').at(1).simulate('click');
     expect(mockProps.onChange).toHaveBeenCalledTimes(1);
     expect(mockProps.onChange).toHaveBeenCalledWith({
       selectedItem: mockProps.items[1]
