@@ -14,14 +14,13 @@ function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) r
  * This source code is licensed under the Apache-2.0 license found in the
  * LICENSE file in the root directory of this source tree.
  */
-import { settings } from 'carbon-components';
 import cx from 'classnames';
 import PropTypes from 'prop-types';
 import React, { useRef } from 'react';
 import Filename from './Filename';
 import { keys, matches } from '../../internal/keyboard';
 import uid from '../../tools/uniqueId';
-var prefix = settings.prefix;
+import { usePrefix } from '../../internal/usePrefix';
 
 function FileUploaderItem(_ref) {
   var _cx;
@@ -37,6 +36,8 @@ function FileUploaderItem(_ref) {
       size = _ref.size,
       other = _objectWithoutProperties(_ref, _excluded);
 
+  var prefix = usePrefix();
+
   var _useRef = useRef(uuid || uid()),
       id = _useRef.current;
 
