@@ -17,8 +17,7 @@ function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) r
 import PropTypes from 'prop-types';
 import React from 'react';
 import classnames from 'classnames';
-import { settings } from 'carbon-components';
-var prefix = settings.prefix;
+import { usePrefix } from '../../internal/usePrefix';
 
 var Link = function Link(_ref) {
   var _classnames;
@@ -33,6 +32,7 @@ var Link = function Link(_ref) {
       size = _ref.size,
       other = _objectWithoutProperties(_ref, _excluded);
 
+  var prefix = usePrefix();
   var classNames = classnames("".concat(prefix, "--link"), className, (_classnames = {}, _defineProperty(_classnames, "".concat(prefix, "--link--disabled"), disabled), _defineProperty(_classnames, "".concat(prefix, "--link--inline"), inline), _defineProperty(_classnames, "".concat(prefix, "--link--visited"), visited), _defineProperty(_classnames, "".concat(prefix, "--link--").concat(size), size), _classnames));
   var Tag = disabled ? 'p' : 'a';
   var rel = other.target === '_blank' ? 'noopener' : null;
