@@ -1,3 +1,5 @@
+var _excluded = ["children", "className"];
+
 function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }
 
 function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = _objectWithoutPropertiesLoose(source, excluded); var key, i; if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }
@@ -19,7 +21,7 @@ var prefix = settings.prefix;
 var ListItem = function ListItem(_ref) {
   var children = _ref.children,
       className = _ref.className,
-      other = _objectWithoutProperties(_ref, ["children", "className"]);
+      other = _objectWithoutProperties(_ref, _excluded);
 
   var classNames = classnames("".concat(prefix, "--list__item"), className);
   return /*#__PURE__*/React.createElement("li", _extends({
