@@ -1,4 +1,4 @@
-var _excluded = ["autoclose", "children", "id", "level", "open", "size", "x", "y", "onClose"];
+var _excluded = ["children", "id", "level", "open", "size", "x", "y", "onClose"];
 
 function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }
 
@@ -32,7 +32,6 @@ import classnames from 'classnames';
 import PropTypes from 'prop-types';
 import { settings } from 'carbon-components';
 import { keys, match } from '../../internal/keyboard';
-import ClickListener from '../../internal/ClickListener';
 import { capWithinRange, clickedElementHasSubnodes, focusNode as focusNodeUtil, getNextNode, getParentMenu, getParentNode, getPosition, getValidNodes, resetFocus } from './_utils';
 import MenuGroup from './MenuGroup';
 import MenuRadioGroup from './MenuRadioGroup';
@@ -46,9 +45,7 @@ var defaultSize = 'sm';
 var Menu = function Menu(_ref) {
   var _classnames;
 
-  var _ref$autoclose = _ref.autoclose,
-      autoclose = _ref$autoclose === void 0 ? true : _ref$autoclose,
-      children = _ref.children,
+  var children = _ref.children,
       id = _ref.id,
       _ref$level = _ref.level,
       level = _ref$level === void 0 ? 1 : _ref$level,
@@ -76,11 +73,6 @@ var Menu = function Menu(_ref) {
       position = _useState4[0],
       setPosition = _useState4[1];
 
-  var _useState5 = useState(false),
-      _useState6 = _slicedToArray(_useState5, 2),
-      canBeClosed = _useState6[0],
-      setCanBeClosed = _useState6[1];
-
   var isRootMenu = level === 1;
   var focusReturn = useRef(null);
 
@@ -119,9 +111,9 @@ var Menu = function Menu(_ref) {
     var targetBoundaries = [xIsRange ? x[0] : x, yIsRange ? y[0] : y, xIsRange ? x[1] : x, yIsRange ? y[1] : y];
 
     if (!isRootMenu) {
-      var _getParentMenu, _rootRef$current;
+      var _getParentMenu;
 
-      var _getParentMenu$getBou = (_getParentMenu = getParentMenu(rootRef === null || rootRef === void 0 ? void 0 : (_rootRef$current = rootRef.current) === null || _rootRef$current === void 0 ? void 0 : _rootRef$current.element)) === null || _getParentMenu === void 0 ? void 0 : _getParentMenu.getBoundingClientRect(),
+      var _getParentMenu$getBou = (_getParentMenu = getParentMenu(rootRef.current)) === null || _getParentMenu === void 0 ? void 0 : _getParentMenu.getBoundingClientRect(),
           parentWidth = _getParentMenu$getBou.width;
 
       targetBoundaries[2] -= parentWidth;
@@ -133,9 +125,7 @@ var Menu = function Menu(_ref) {
 
   function focusNode(node) {
     if (node) {
-      var _rootRef$current2;
-
-      resetFocus(rootRef === null || rootRef === void 0 ? void 0 : (_rootRef$current2 = rootRef.current) === null || _rootRef$current2 === void 0 ? void 0 : _rootRef$current2.element);
+      resetFocus(rootRef.current);
       focusNodeUtil(node);
     }
   }
@@ -193,16 +183,10 @@ var Menu = function Menu(_ref) {
     }
   }
 
-  function handleClickOutside(event) {
-    if (!clickedElementHasSubnodes(event) && open && canBeClosed && autoclose) {
-      close(event.type);
-    }
-  }
-
   function getCorrectedPosition(preferredDirection) {
-    var _rootRef$current3, _rootRef$current3$ele;
+    var _rootRef$current;
 
-    var elementRect = rootRef === null || rootRef === void 0 ? void 0 : (_rootRef$current3 = rootRef.current) === null || _rootRef$current3 === void 0 ? void 0 : (_rootRef$current3$ele = _rootRef$current3.element) === null || _rootRef$current3$ele === void 0 ? void 0 : _rootRef$current3$ele.getBoundingClientRect();
+    var elementRect = (_rootRef$current = rootRef.current) === null || _rootRef$current === void 0 ? void 0 : _rootRef$current.getBoundingClientRect();
     var elementDimensions = [elementRect.width, elementRect.height];
     var targetBoundaries = getTargetBoundaries();
     var containerBoundaries = getContainerBoundaries();
@@ -216,28 +200,24 @@ var Menu = function Menu(_ref) {
   }
 
   function handleBlur(event) {
-    var _rootRef$current4;
+    var _rootRef$current2;
 
-    if (isRootMenu && !(rootRef !== null && rootRef !== void 0 && (_rootRef$current4 = rootRef.current) !== null && _rootRef$current4 !== void 0 && _rootRef$current4.element.contains(event.relatedTarget))) {
+    if (isRootMenu && !((_rootRef$current2 = rootRef.current) !== null && _rootRef$current2 !== void 0 && _rootRef$current2.contains(event.relatedTarget))) {
       close(event.type);
     }
   }
 
   useEffect(function () {
-    setCanBeClosed(false);
-
     if (open) {
       focusReturn.current = document.activeElement;
       var localDirection = 1;
 
       if (isRootMenu) {
-        var _rootRef$current5, _rootRef$current5$ele;
+        var _rootRef$current3;
 
-        rootRef === null || rootRef === void 0 ? void 0 : (_rootRef$current5 = rootRef.current) === null || _rootRef$current5 === void 0 ? void 0 : (_rootRef$current5$ele = _rootRef$current5.element) === null || _rootRef$current5$ele === void 0 ? void 0 : _rootRef$current5$ele.focus();
+        (_rootRef$current3 = rootRef.current) === null || _rootRef$current3 === void 0 ? void 0 : _rootRef$current3.focus();
       } else {
-        var _rootRef$current6;
-
-        var parentMenu = getParentMenu(rootRef === null || rootRef === void 0 ? void 0 : (_rootRef$current6 = rootRef.current) === null || _rootRef$current6 === void 0 ? void 0 : _rootRef$current6.element);
+        var parentMenu = getParentMenu(rootRef.current);
 
         if (parentMenu) {
           localDirection = Number(parentMenu.dataset.direction);
@@ -246,7 +226,6 @@ var Menu = function Menu(_ref) {
 
       var correctedPosition = getCorrectedPosition(localDirection);
       setPosition(correctedPosition);
-      setCanBeClosed(true);
     } else {
       setPosition([0, 0]);
     } // eslint-disable-next-line react-hooks/exhaustive-deps
@@ -266,6 +245,7 @@ var Menu = function Menu(_ref) {
   var classes = classnames("".concat(prefix, "--menu"), (_classnames = {}, _defineProperty(_classnames, "".concat(prefix, "--menu--open"), open), _defineProperty(_classnames, "".concat(prefix, "--menu--invisible"), open && position[0] === 0 && position[1] === 0), _defineProperty(_classnames, "".concat(prefix, "--menu--root"), isRootMenu), _classnames), size !== defaultSize && "".concat(prefix, "--menu--").concat(size));
   var ulAttributes = {
     id: id,
+    ref: rootRef,
     className: classes,
     onKeyDown: handleKeyDown,
     onClick: handleClick,
@@ -300,20 +280,11 @@ var Menu = function Menu(_ref) {
     childrenToRender = React.Children.toArray(options[0].props.children);
   }
 
-  var menu = /*#__PURE__*/React.createElement(ClickListener, {
-    onClickOutside: handleClickOutside,
-    ref: rootRef
-  }, /*#__PURE__*/React.createElement("ul", ulAttributes, childrenToRender));
+  var menu = /*#__PURE__*/React.createElement("ul", ulAttributes, childrenToRender);
   return isRootMenu ? open && /*#__PURE__*/ReactDOM.createPortal(menu, document.body) || null : menu;
 };
 
 Menu.propTypes = {
-  /**
-   * Whether or not the menu should automatically close when
-   * an outside click is registered
-   */
-  autoclose: PropTypes.bool,
-
   /**
    * Specify the children of the Menu
    */
