@@ -35,16 +35,16 @@ function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) r
 import PropTypes from 'prop-types';
 import React, { useEffect, useRef, useState } from 'react';
 import cx from 'classnames';
-import { settings } from 'carbon-components';
 import { Close20, ErrorFilled20, CheckmarkFilled20, WarningFilled20, WarningAltFilled20, InformationFilled20, InformationSquareFilled20 } from '@carbon/icons-react';
 import Button from '../Button';
-var prefix = settings.prefix;
+import { usePrefix } from '../../internal/usePrefix';
 export function NotificationActionButton(_ref) {
   var children = _ref.children,
       customClassName = _ref.className,
       onClick = _ref.onClick,
       rest = _objectWithoutProperties(_ref, _excluded);
 
+  var prefix = usePrefix();
   var className = cx(customClassName, "".concat(prefix, "--inline-notification__action-button"));
   return /*#__PURE__*/React.createElement(Button, _extends({
     className: className,
@@ -79,6 +79,7 @@ export function NotificationButton(_ref2) {
       notificationType = _ref2.notificationType,
       rest = _objectWithoutProperties(_ref2, _excluded2);
 
+  var prefix = usePrefix();
   var buttonClassName = cx(className, _defineProperty({}, "".concat(prefix, "--").concat(notificationType, "-notification__close-button"), notificationType));
   var iconClassName = cx(_defineProperty({}, "".concat(prefix, "--").concat(notificationType, "-notification__close-icon"), notificationType));
   return /*#__PURE__*/React.createElement("button", _extends({}, rest, {
@@ -147,6 +148,8 @@ export function NotificationTextDetails(_ref3) {
       children = _ref3.children,
       rest = _objectWithoutProperties(_ref3, _excluded3);
 
+  var prefix = usePrefix();
+
   if (notificationType === 'toast') {
     return /*#__PURE__*/React.createElement("div", _extends({}, rest, {
       className: "".concat(prefix, "--toast-notification__details")
@@ -209,6 +212,7 @@ function NotificationIcon(_ref4) {
   var iconDescription = _ref4.iconDescription,
       kind = _ref4.kind,
       notificationType = _ref4.notificationType;
+  var prefix = usePrefix();
   var IconForKind = iconTypes[kind];
 
   if (!IconForKind) {
@@ -245,6 +249,8 @@ export function ToastNotification(_ref5) {
       timeout = _ref5.timeout,
       rest = _objectWithoutProperties(_ref5, _excluded4);
 
+  var prefix = usePrefix();
+
   var _useState = useState(true),
       _useState2 = _slicedToArray(_useState, 2),
       isOpen = _useState2[0],
@@ -414,6 +420,8 @@ export function InlineNotification(_ref6) {
       children = _ref6.children,
       rest = _objectWithoutProperties(_ref6, _excluded5);
 
+  var prefix = usePrefix();
+
   var _useState3 = useState(true),
       _useState4 = _slicedToArray(_useState3, 2),
       isOpen = _useState4[0],
