@@ -17,8 +17,7 @@ function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) r
 import PropTypes from 'prop-types';
 import React from 'react';
 import classnames from 'classnames';
-import { settings } from 'carbon-components';
-var prefix = settings.prefix;
+import { usePrefix } from '../../internal/usePrefix';
 
 var OrderedList = function OrderedList(_ref) {
   var _classnames;
@@ -30,6 +29,7 @@ var OrderedList = function OrderedList(_ref) {
       isExpressive = _ref.isExpressive,
       other = _objectWithoutProperties(_ref, _excluded);
 
+  var prefix = usePrefix();
   var classNames = classnames((_classnames = {}, _defineProperty(_classnames, "".concat(prefix, "--list--ordered"), !native), _defineProperty(_classnames, "".concat(prefix, "--list--ordered--native"), native), _defineProperty(_classnames, "".concat(prefix, "--list--nested"), nested), _defineProperty(_classnames, "".concat(prefix, "--list--expressive"), isExpressive), _classnames), className);
   return /*#__PURE__*/React.createElement("ol", _extends({
     className: classNames
