@@ -40,10 +40,9 @@ function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) r
 import PropTypes from 'prop-types';
 import React, { Component } from 'react';
 import classnames from 'classnames';
-import { settings } from 'carbon-components';
 import { CheckmarkOutline16, Warning16, RadioButton16, CircleFilled16 } from '@carbon/icons-react';
 import { keys, matches } from '../../internal/keyboard';
-var prefix = settings.prefix;
+import { usePrefix, PrefixContext } from '../../internal/usePrefix';
 
 var defaultRenderLabel = function defaultRenderLabel(props) {
   return /*#__PURE__*/React.createElement("p", props);
@@ -76,6 +75,7 @@ export function ProgressStep(_ref) {
       t = _ref.translateWithId,
       rest = _objectWithoutProperties(_ref, _excluded);
 
+  var prefix = usePrefix();
   var classes = classnames((_classnames = {}, _defineProperty(_classnames, "".concat(prefix, "--progress-step"), true), _defineProperty(_classnames, "".concat(prefix, "--progress-step--current"), current), _defineProperty(_classnames, "".concat(prefix, "--progress-step--complete"), complete), _defineProperty(_classnames, "".concat(prefix, "--progress-step--incomplete"), !complete && !current), _defineProperty(_classnames, "".concat(prefix, "--progress-step--disabled"), disabled), _defineProperty(_classnames, className, className), _classnames));
 
   var handleKeyDown = function handleKeyDown(e) {
@@ -142,11 +142,13 @@ export function ProgressStep(_ref) {
     description: description,
     invalid: invalid,
     prefix: prefix
-  }), /*#__PURE__*/React.createElement(ProgressStepLabel, {
+  }), /*#__PURE__*/React.createElement("div", {
+    className: "".concat(prefix, "--progress-text")
+  }, /*#__PURE__*/React.createElement(ProgressStepLabel, {
     className: "".concat(prefix, "--progress-label")
   }, label), secondaryLabel !== null && secondaryLabel !== undefined ? /*#__PURE__*/React.createElement("p", {
     className: "".concat(prefix, "--progress-optional")
-  }, secondaryLabel) : null, /*#__PURE__*/React.createElement("span", {
+  }, secondaryLabel) : null), /*#__PURE__*/React.createElement("span", {
     className: "".concat(prefix, "--progress-line")
   })));
 }
@@ -296,6 +298,7 @@ export var ProgressIndicator = /*#__PURE__*/function (_Component) {
           spaceEqually = _this$props.spaceEqually,
           other = _objectWithoutProperties(_this$props, _excluded2);
 
+      var prefix = this.context;
       var classes = classnames((_classnames3 = {}, _defineProperty(_classnames3, "".concat(prefix, "--progress"), true), _defineProperty(_classnames3, "".concat(prefix, "--progress--vertical"), vertical), _defineProperty(_classnames3, "".concat(prefix, "--progress--space-equal"), spaceEqually && !vertical), _defineProperty(_classnames3, className, className), _classnames3));
       return /*#__PURE__*/React.createElement("ul", _extends({
         className: classes
@@ -349,6 +352,8 @@ _defineProperty(ProgressIndicator, "propTypes", {
   vertical: PropTypes.bool
 });
 
+_defineProperty(ProgressIndicator, "contextType", PrefixContext);
+
 _defineProperty(ProgressIndicator, "defaultProps", {
   currentIndex: 0
 });
\ No newline at end of file
