@@ -39,12 +39,11 @@ function _defineProperty(obj, key, value) { if (key in obj) { Object.definePrope
 import PropTypes from 'prop-types';
 import React from 'react';
 import classNames from 'classnames';
-import { settings } from 'carbon-components';
 import { ChevronLeft16, ChevronRight16 } from '@carbon/icons-react';
 import debounce from 'lodash.debounce';
 import { keys, match, matches } from '../../internal/keyboard';
 import TabContent from '../TabContent';
-var prefix = settings.prefix;
+import { PrefixContext } from '../../internal/usePrefix';
 
 var Tabs = /*#__PURE__*/function (_React$Component) {
   _inherits(Tabs, _React$Component);
@@ -409,6 +408,8 @@ var Tabs = /*#__PURE__*/function (_React$Component) {
           leftOverflowButtonProps = _this$props.leftOverflowButtonProps,
           rightOverflowButtonProps = _this$props.rightOverflowButtonProps,
           other = _objectWithoutProperties(_this$props, _excluded);
+
+      var prefix = this.context;
       /**
        * The tab panel acts like a tab panel when the screen is wider, but acts
        * like a select list when the screen is narrow.  In the wide case we want
@@ -422,7 +423,6 @@ var Tabs = /*#__PURE__*/function (_React$Component) {
        * panel and separate components when it looks like a select list.
        */
 
-
       var tabsWithProps = this.getTabs().map(function (tab, index) {
         var tabIndex = index === _this2.state.selected ? 0 : -1;
         var newTab = /*#__PURE__*/React.cloneElement(tab, {
@@ -620,4 +620,6 @@ _defineProperty(Tabs, "defaultProps", {
   selectionMode: 'automatic'
 });
 
+_defineProperty(Tabs, "contextType", PrefixContext);
+
 export { Tabs as default };
\ No newline at end of file
