@@ -1,7 +1,7 @@
 function _typeof(obj) { "@babel/helpers - typeof"; if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") { _typeof = function _typeof(obj) { return typeof obj; }; } else { _typeof = function _typeof(obj) { return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; }; } return _typeof(obj); }
 
 var _excluded = ["children", "className", "light"],
-    _excluded2 = ["children", "href", "className", "handleClick", "handleKeyDown", "clicked", "light"],
+    _excluded2 = ["children", "href", "className", "handleClick", "handleKeyDown", "onClick", "onKeyDown", "clicked", "light"],
     _excluded3 = ["children", "id", "tabIndex", "value", "name", "title", "iconDescription", "className", "handleClick", "handleKeyDown", "onClick", "onChange", "onKeyDown", "light", "disabled", "selected"],
     _excluded4 = ["tabIndex", "className", "expanded", "tileMaxHeight", "tilePadding", "handleClick", "onClick", "onKeyUp", "tileCollapsedIconText", "tileExpandedIconText", "tileCollapsedLabel", "tileExpandedLabel", "onBeforeClick", "light"];
 
@@ -53,14 +53,13 @@ function _defineProperty(obj, key, value) { if (key in obj) { Object.definePrope
  */
 import React, { Component, useEffect, useRef, useState } from 'react';
 import PropTypes from 'prop-types';
-import classNames from 'classnames';
-import { settings } from 'carbon-components';
+import cx from 'classnames';
 import Link from '../Link';
 import { Checkbox16, CheckboxCheckedFilled16, ChevronDown16 } from '@carbon/icons-react';
 import { keys, matches } from '../../internal/keyboard';
 import deprecate from '../../prop-types/deprecate';
 import { composeEventHandlers } from '../../tools/events';
-var prefix = settings.prefix;
+import { PrefixContext, usePrefix } from '../../internal/usePrefix';
 export var Tile = /*#__PURE__*/function (_Component) {
   _inherits(Tile, _Component);
 
@@ -75,16 +74,18 @@ export var Tile = /*#__PURE__*/function (_Component) {
   _createClass(Tile, [{
     key: "render",
     value: function render() {
+      var prefix = this.context;
+
       var _this$props = this.props,
           children = _this$props.children,
           className = _this$props.className,
           light = _this$props.light,
-          other = _objectWithoutProperties(_this$props, _excluded);
+          rest = _objectWithoutProperties(_this$props, _excluded);
 
-      var tileClasses = classNames("".concat(prefix, "--tile"), _defineProperty({}, "".concat(prefix, "--tile--light"), light), className);
+      var tileClasses = cx("".concat(prefix, "--tile"), _defineProperty({}, "".concat(prefix, "--tile--light"), light), className);
       return /*#__PURE__*/React.createElement("div", _extends({
         className: tileClasses
-      }, other), children);
+      }, rest), children);
     }
   }]);
 
@@ -109,6 +110,8 @@ _defineProperty(Tile, "propTypes", {
   light: PropTypes.bool
 });
 
+_defineProperty(Tile, "contextType", PrefixContext);
+
 _defineProperty(Tile, "defaultProps", {
   light: false
 });
@@ -137,7 +140,10 @@ export var ClickableTile = /*#__PURE__*/function (_Component2) {
       _this.setState({
         clicked: !_this.state.clicked
       }, function () {
-        _this.props.handleClick(evt);
+        var _this$props$handleCli, _this$props2, _this$props$onClick, _this$props3;
+
+        // TODO: Remove handleClick prop when handleClick is deprecated
+        ((_this$props$handleCli = (_this$props2 = _this.props).handleClick) === null || _this$props$handleCli === void 0 ? void 0 : _this$props$handleCli.call(_this$props2, evt)) || ((_this$props$onClick = (_this$props3 = _this.props).onClick) === null || _this$props$onClick === void 0 ? void 0 : _this$props$onClick.call(_this$props3, evt));
       });
     });
 
@@ -148,10 +154,16 @@ export var ClickableTile = /*#__PURE__*/function (_Component2) {
         _this.setState({
           clicked: !_this.state.clicked
         }, function () {
-          _this.props.handleKeyDown(evt);
+          var _this$props$handleKey, _this$props4;
+
+          // TODO: Remove handleKeyDown prop when handleKeyDown is deprecated
+          ((_this$props$handleKey = (_this$props4 = _this.props).handleKeyDown) === null || _this$props$handleKey === void 0 ? void 0 : _this$props$handleKey.call(_this$props4, evt)) || _this.props.onKeyDown(evt);
         });
       } else {
-        _this.props.handleKeyDown(evt);
+        var _this$props$handleKey2, _this$props5;
+
+        // TODO: Remove handleKeyDown prop when handleKeyDown is deprecated
+        ((_this$props$handleKey2 = (_this$props5 = _this.props).handleKeyDown) === null || _this$props$handleKey2 === void 0 ? void 0 : _this$props$handleKey2.call(_this$props5, evt)) || _this.props.onKeyDown(evt);
       }
     });
 
@@ -161,23 +173,27 @@ export var ClickableTile = /*#__PURE__*/function (_Component2) {
   _createClass(ClickableTile, [{
     key: "render",
     value: function render() {
-      var _classNames2;
+      var _cx2;
 
-      var _this$props2 = this.props,
-          children = _this$props2.children,
-          href = _this$props2.href,
-          className = _this$props2.className,
-          handleClick = _this$props2.handleClick,
-          handleKeyDown = _this$props2.handleKeyDown,
-          clicked = _this$props2.clicked,
-          light = _this$props2.light,
-          other = _objectWithoutProperties(_this$props2, _excluded2);
+      var prefix = this.context;
 
-      var classes = classNames("".concat(prefix, "--tile"), "".concat(prefix, "--tile--clickable"), (_classNames2 = {}, _defineProperty(_classNames2, "".concat(prefix, "--tile--is-clicked"), this.state.clicked), _defineProperty(_classNames2, "".concat(prefix, "--tile--light"), light), _classNames2), className);
+      var _this$props6 = this.props,
+          children = _this$props6.children,
+          href = _this$props6.href,
+          className = _this$props6.className,
+          handleClick = _this$props6.handleClick,
+          handleKeyDown = _this$props6.handleKeyDown,
+          onClick = _this$props6.onClick,
+          onKeyDown = _this$props6.onKeyDown,
+          clicked = _this$props6.clicked,
+          light = _this$props6.light,
+          rest = _objectWithoutProperties(_this$props6, _excluded2);
+
+      var classes = cx("".concat(prefix, "--tile"), "".concat(prefix, "--tile--clickable"), (_cx2 = {}, _defineProperty(_cx2, "".concat(prefix, "--tile--is-clicked"), this.state.clicked), _defineProperty(_cx2, "".concat(prefix, "--tile--light"), light), _cx2), className);
       return /*#__PURE__*/React.createElement(Link, _extends({
         href: href,
         className: classes
-      }, other, {
+      }, rest, {
         onClick: this.handleClick,
         onKeyDown: this.handleKeyDown
       }), children);
@@ -210,14 +226,14 @@ _defineProperty(ClickableTile, "propTypes", {
   className: PropTypes.string,
 
   /**
-   * Specify the function to run when the ClickableTile is clicked
+   * Deprecated in v11. Use 'onClick' instead.
    */
-  handleClick: PropTypes.func,
+  handleClick: deprecate(PropTypes.func, 'The handleClick prop for ClickableTile has been deprecated in favor of onClick. It will be removed in the next major release.'),
 
   /**
    * Specify the function to run when the ClickableTile is interacted with via a keyboard
    */
-  handleKeyDown: PropTypes.func,
+  handleKeyDown: deprecate(PropTypes.func, 'The handleKeyDown prop for ClickableTile has been deprecated in favor of onKeyDown. It will be removed in the next major release.'),
 
   /**
    * The href for the link.
@@ -230,26 +246,37 @@ _defineProperty(ClickableTile, "propTypes", {
    */
   light: PropTypes.bool,
 
+  /**
+   * Specify the function to run when the ClickableTile is clicked
+   */
+  onClick: PropTypes.func,
+
+  /**
+   * Specify the function to run when the ClickableTile is interacted with via a keyboard
+   */
+  onKeyDown: PropTypes.func,
+
   /**
    * The rel property for the link.
    */
   rel: PropTypes.string
 });
 
+_defineProperty(ClickableTile, "contextType", PrefixContext);
+
 _defineProperty(ClickableTile, "defaultProps", {
   clicked: false,
-  handleClick: function handleClick() {},
-  handleKeyDown: function handleKeyDown() {},
+  onClick: function onClick() {},
+  onKeyDown: function onKeyDown() {},
   light: false
 });
 
 export function SelectableTile(props) {
-  var _classNames3;
+  var _cx3;
 
   var children = props.children,
       id = props.id,
-      _props$tabIndex = props.tabIndex,
-      tabIndex = _props$tabIndex === void 0 ? 0 : _props$tabIndex,
+      tabIndex = props.tabIndex,
       value = props.value,
       name = props.name,
       title = props.title,
@@ -257,19 +284,17 @@ export function SelectableTile(props) {
       className = props.className,
       handleClick = props.handleClick,
       handleKeyDown = props.handleKeyDown,
-      _props$onClick = props.onClick,
-      onClick = _props$onClick === void 0 ? function () {} : _props$onClick,
-      _props$onChange = props.onChange,
-      onChange = _props$onChange === void 0 ? function () {} : _props$onChange,
-      _props$onKeyDown = props.onKeyDown,
-      onKeyDown = _props$onKeyDown === void 0 ? function () {} : _props$onKeyDown,
+      onClick = props.onClick,
+      onChange = props.onChange,
+      onKeyDown = props.onKeyDown,
       light = props.light,
       disabled = props.disabled,
       selected = props.selected,
-      other = _objectWithoutProperties(props, _excluded3); // TODO: replace with onClick when handleClick prop is deprecated
+      rest = _objectWithoutProperties(props, _excluded3);
 
+  var prefix = usePrefix(); // TODO: replace with onClick when handleClick prop is deprecated
 
-  var clickHandler = handleClick || onClick; // TODO: replace with onClick when handleClick prop is deprecated
+  var clickHandler = handleClick || onClick; // TODO: replace with onKeyDown when handleKeyDown prop is deprecated
 
   var keyDownHandler = handleKeyDown || onKeyDown;
 
@@ -279,8 +304,8 @@ export function SelectableTile(props) {
       setIsSelected = _useState2[1];
 
   var input = useRef(null);
-  var classes = classNames("".concat(prefix, "--tile"), "".concat(prefix, "--tile--selectable"), (_classNames3 = {}, _defineProperty(_classNames3, "".concat(prefix, "--tile--is-selected"), isSelected), _defineProperty(_classNames3, "".concat(prefix, "--tile--light"), light), _defineProperty(_classNames3, "".concat(prefix, "--tile--disabled"), disabled), _classNames3), className);
-  var inputClasses = classNames("".concat(prefix, "--tile-input"), _defineProperty({}, "".concat(prefix, "--tile-input--checked"), isSelected)); // TODO: rename to handleClick when handleClick prop is deprecated
+  var classes = cx("".concat(prefix, "--tile"), "".concat(prefix, "--tile--selectable"), (_cx3 = {}, _defineProperty(_cx3, "".concat(prefix, "--tile--is-selected"), isSelected), _defineProperty(_cx3, "".concat(prefix, "--tile--light"), light), _defineProperty(_cx3, "".concat(prefix, "--tile--disabled"), disabled), _cx3), className);
+  var inputClasses = cx("".concat(prefix, "--tile-input"), _defineProperty({}, "".concat(prefix, "--tile-input--checked"), isSelected)); // TODO: rename to handleClick when handleClick prop is deprecated
 
   function handleOnClick(evt) {
     evt.preventDefault();
@@ -328,7 +353,7 @@ export function SelectableTile(props) {
     className: classes // eslint-disable-next-line jsx-a11y/no-noninteractive-tabindex
     ,
     tabIndex: !disabled ? tabIndex : null
-  }, other, {
+  }, rest, {
     onClick: !disabled ? handleOnClick : null,
     onKeyDown: !disabled ? handleOnKeyDown : null
   }), /*#__PURE__*/React.createElement("span", {
@@ -342,7 +367,10 @@ SelectableTile.defaultProps = {
   title: 'title',
   selected: false,
   tabIndex: 0,
-  light: false
+  light: false,
+  onClick: function onClick() {},
+  onChange: function onChange() {},
+  onKeyDown: function onKeyDown() {}
 };
 SelectableTile.propTypes = {
   /**
@@ -481,9 +509,12 @@ export var ExpandableTile = /*#__PURE__*/function (_Component3) {
       _this2.setState({
         expanded: !_this2.state.expanded
       }, function () {
-        _this2.setMaxHeight();
+        var _this2$props$handleCl, _this2$props, _this2$props$onClick, _this2$props2;
 
-        _this2.props.handleClick(evt);
+        _this2.setMaxHeight(); // TODO: Remove handleClick prop when handleClick is deprecated
+
+
+        ((_this2$props$handleCl = (_this2$props = _this2.props).handleClick) === null || _this2$props$handleCl === void 0 ? void 0 : _this2$props$handleCl.call(_this2$props, evt)) || ((_this2$props$onClick = (_this2$props2 = _this2.props).onClick) === null || _this2$props$onClick === void 0 ? void 0 : _this2$props$onClick.call(_this2$props2, evt));
       });
     });
 
@@ -505,28 +536,29 @@ export var ExpandableTile = /*#__PURE__*/function (_Component3) {
   _createClass(ExpandableTile, [{
     key: "render",
     value: function render() {
-      var _classNames5,
+      var _cx5,
           _this3 = this;
 
-      var _this$props3 = this.props,
-          tabIndex = _this$props3.tabIndex,
-          className = _this$props3.className,
-          expanded = _this$props3.expanded,
-          tileMaxHeight = _this$props3.tileMaxHeight,
-          tilePadding = _this$props3.tilePadding,
-          handleClick = _this$props3.handleClick,
-          onClick = _this$props3.onClick,
-          onKeyUp = _this$props3.onKeyUp,
-          tileCollapsedIconText = _this$props3.tileCollapsedIconText,
-          tileExpandedIconText = _this$props3.tileExpandedIconText,
-          tileCollapsedLabel = _this$props3.tileCollapsedLabel,
-          tileExpandedLabel = _this$props3.tileExpandedLabel,
-          onBeforeClick = _this$props3.onBeforeClick,
-          light = _this$props3.light,
-          other = _objectWithoutProperties(_this$props3, _excluded4);
+      var _this$props7 = this.props,
+          tabIndex = _this$props7.tabIndex,
+          className = _this$props7.className,
+          expanded = _this$props7.expanded,
+          tileMaxHeight = _this$props7.tileMaxHeight,
+          tilePadding = _this$props7.tilePadding,
+          handleClick = _this$props7.handleClick,
+          onClick = _this$props7.onClick,
+          onKeyUp = _this$props7.onKeyUp,
+          tileCollapsedIconText = _this$props7.tileCollapsedIconText,
+          tileExpandedIconText = _this$props7.tileExpandedIconText,
+          tileCollapsedLabel = _this$props7.tileCollapsedLabel,
+          tileExpandedLabel = _this$props7.tileExpandedLabel,
+          onBeforeClick = _this$props7.onBeforeClick,
+          light = _this$props7.light,
+          rest = _objectWithoutProperties(_this$props7, _excluded4);
 
+      var prefix = this.context;
       var isExpanded = this.state.expanded;
-      var classes = classNames("".concat(prefix, "--tile"), "".concat(prefix, "--tile--expandable"), (_classNames5 = {}, _defineProperty(_classNames5, "".concat(prefix, "--tile--is-expanded"), isExpanded), _defineProperty(_classNames5, "".concat(prefix, "--tile--light"), light), _classNames5), className);
+      var classes = cx("".concat(prefix, "--tile"), "".concat(prefix, "--tile--expandable"), (_cx5 = {}, _defineProperty(_cx5, "".concat(prefix, "--tile--is-expanded"), isExpanded), _defineProperty(_cx5, "".concat(prefix, "--tile--light"), light), _cx5), className);
       var tileStyle = {
         maxHeight: isExpanded ? null : this.state.tileMaxHeight + this.state.tilePadding
       };
@@ -543,7 +575,7 @@ export var ExpandableTile = /*#__PURE__*/function (_Component3) {
           className: classes,
           "aria-expanded": isExpanded,
           title: isExpanded ? tileExpandedIconText : tileCollapsedIconText
-        }, other, {
+        }, rest, {
           onKeyUp: composeEventHandlers([onKeyUp, this.handleKeyUp]),
           onClick: composeEventHandlers([onClick, this.handleClick]),
           tabIndex: tabIndex
@@ -610,9 +642,9 @@ _defineProperty(ExpandableTile, "propTypes", {
   expanded: PropTypes.bool,
 
   /**
-   * Specify the function to run when the ExpandableTile is clicked
+   * Deprecated in v11. Use 'onClick' instead.
    */
-  handleClick: PropTypes.func,
+  handleClick: deprecate(PropTypes.func, 'The handleClick prop for ClickableTile has been deprecated in favor of onClick. It will be removed in the next major release.'),
 
   /**
    * An ID that can be provided to aria-labelledby
@@ -631,8 +663,8 @@ _defineProperty(ExpandableTile, "propTypes", {
   onBeforeClick: PropTypes.func,
 
   /**
-   * optional handler to trigger a function the Tile is clicked
-   */
+   * Specify the function to run when the ExpandableTile is clicked
+    */
   onClick: PropTypes.func,
 
   /**
@@ -666,6 +698,8 @@ _defineProperty(ExpandableTile, "propTypes", {
   tileExpandedLabel: PropTypes.string
 });
 
+_defineProperty(ExpandableTile, "contextType", PrefixContext);
+
 _defineProperty(ExpandableTile, "defaultProps", {
   tabIndex: 0,
   expanded: false,
@@ -674,7 +708,7 @@ _defineProperty(ExpandableTile, "defaultProps", {
   onBeforeClick: function onBeforeClick() {
     return true;
   },
-  handleClick: function handleClick() {},
+  onClick: function onClick() {},
   tileCollapsedIconText: 'Interact to expand Tile',
   tileExpandedIconText: 'Interact to collapse Tile',
   light: false
@@ -694,6 +728,7 @@ export var TileAboveTheFoldContent = /*#__PURE__*/function (_Component4) {
   _createClass(TileAboveTheFoldContent, [{
     key: "render",
     value: function render() {
+      var prefix = this.context;
       var children = this.props.children;
       return /*#__PURE__*/React.createElement("span", {
         className: "".concat(prefix, "--tile-content__above-the-fold")
@@ -711,6 +746,8 @@ _defineProperty(TileAboveTheFoldContent, "propTypes", {
   children: PropTypes.node
 });
 
+_defineProperty(TileAboveTheFoldContent, "contextType", PrefixContext);
+
 export var TileBelowTheFoldContent = /*#__PURE__*/function (_Component5) {
   _inherits(TileBelowTheFoldContent, _Component5);
 
@@ -726,6 +763,7 @@ export var TileBelowTheFoldContent = /*#__PURE__*/function (_Component5) {
     key: "render",
     value: function render() {
       var children = this.props.children;
+      var prefix = this.context;
       return /*#__PURE__*/React.createElement("span", {
         className: "".concat(prefix, "--tile-content__below-the-fold")
       }, children);
@@ -740,4 +778,6 @@ _defineProperty(TileBelowTheFoldContent, "propTypes", {
    * The child nodes.
    */
   children: PropTypes.node
-});
\ No newline at end of file
+});
+
+_defineProperty(TileBelowTheFoldContent, "contextType", PrefixContext);
\ No newline at end of file
