@@ -37,16 +37,28 @@ export default {
   }
 };
 export var Default = function Default() {
+  return /*#__PURE__*/React.createElement(React.Fragment, null, /*#__PURE__*/React.createElement(Toggle, {
+    labelText: "Toggle (md)",
+    size: "md",
+    labelA: "Off",
+    labelB: "On",
+    defaultToggled: true,
+    className: "some-class",
+    id: "toggle-1"
+  }), /*#__PURE__*/React.createElement("br", null), /*#__PURE__*/React.createElement(Toggle, {
+    labelText: "Toggle (sm)",
+    size: "sm",
+    defaultToggled: true,
+    className: "some-class",
+    id: "toggle-2"
+  }));
+};
+export var Playground = function Playground() {
   return /*#__PURE__*/React.createElement(Toggle, _extends({
     defaultToggled: true
   }, toggleProps(), {
     className: "some-class",
-    id: "toggle-1"
+    id: "toggle-3"
   }));
 };
-Default.storyName = 'Toggle';
-Default.parameters = {
-  info: {
-    text: "\n        Toggles are controls that are used to quickly switch between two possible states. The example below shows\n        an uncontrolled Toggle component. To use the Toggle component as a controlled component, set the toggled property.\n        Setting the toggled property will allow you to change the value dynamically, whereas setting the defaultToggled\n        prop will only set the value initially. This example has defaultToggled set to true.\n      "
-  }
-};
\ No newline at end of file
+Default.storyName = 'Toggle';
\ No newline at end of file
