@@ -41,10 +41,9 @@ function _defineProperty(obj, key, value) { if (key in obj) { Object.definePrope
 import PropTypes from 'prop-types';
 import React from 'react';
 import classNames from 'classnames';
-import { settings } from 'carbon-components';
 import setupGetInstanceId from '../../tools/setupGetInstanceId';
 import { keys, match } from '../../internal/keyboard';
-var prefix = settings.prefix;
+import { PrefixContext } from '../../internal/usePrefix';
 var getInstanceId = setupGetInstanceId();
 
 var Toggle = /*#__PURE__*/function (_React$Component) {
@@ -61,6 +60,8 @@ var Toggle = /*#__PURE__*/function (_React$Component) {
   _createClass(Toggle, [{
     key: "render",
     value: function render() {
+      var prefix = this.context;
+
       var _this$props = this.props,
           className = _this$props.className,
           defaultToggled = _this$props.defaultToggled,
@@ -77,7 +78,7 @@ var Toggle = /*#__PURE__*/function (_React$Component) {
 
       var input;
       var wrapperClasses = classNames("".concat(prefix, "--form-item"), _defineProperty({}, className, className));
-      var toggleClasses = classNames("".concat(prefix, "--toggle-input"), _defineProperty({}, "".concat(prefix, "--toggle-input--small"), size));
+      var toggleClasses = classNames("".concat(prefix, "--toggle-input"), _defineProperty({}, "".concat(prefix, "--toggle-input--small"), size === 'sm'));
       var checkedProps = {};
 
       if (typeof toggled !== 'undefined') {
@@ -135,6 +136,8 @@ var Toggle = /*#__PURE__*/function (_React$Component) {
 
 _defineProperty(Toggle, "propTypes", (_defineProperty2 = {}, _defineProperty(_defineProperty2, 'aria-label', PropTypes.string.isRequired), _defineProperty(_defineProperty2, "className", PropTypes.string), _defineProperty(_defineProperty2, "defaultToggled", PropTypes.bool), _defineProperty(_defineProperty2, "id", PropTypes.string.isRequired), _defineProperty(_defineProperty2, "labelA", PropTypes.node.isRequired), _defineProperty(_defineProperty2, "labelB", PropTypes.node.isRequired), _defineProperty(_defineProperty2, "labelText", PropTypes.node), _defineProperty(_defineProperty2, "onChange", PropTypes.func), _defineProperty(_defineProperty2, "onToggle", PropTypes.func), _defineProperty(_defineProperty2, "size", PropTypes.oneOf(['sm', 'md'])), _defineProperty(_defineProperty2, "toggled", PropTypes.bool), _defineProperty2));
 
+_defineProperty(Toggle, "contextType", PrefixContext);
+
 _defineProperty(Toggle, "defaultProps", (_defineProperty3 = {
   defaultToggled: false
 }, _defineProperty(_defineProperty3, 'aria-label', 'Toggle'), _defineProperty(_defineProperty3, "labelA", 'Off'), _defineProperty(_defineProperty3, "labelB", 'On'), _defineProperty(_defineProperty3, "onToggle", function onToggle() {}), _defineProperty3));
