@@ -108,7 +108,7 @@ var Tooltip = /*#__PURE__*/function (_Component) {
     _defineProperty(_assertThisInitialized(_this), "_handleUserInputOpenClose", function (event, _ref2) {
       var open = _ref2.open;
 
-      if (_this.isControlled) {
+      if (_this.isControlled && _this.props.onChange) {
         // Callback to the parent to let them decide what to do
         _this.props.onChange(event, {
           open: open
@@ -226,7 +226,7 @@ var Tooltip = /*#__PURE__*/function (_Component) {
     });
 
     _defineProperty(_assertThisInitialized(_this), "handleKeyPress", function (event) {
-      if (keyDownMatch(event, [keys.Escape])) {
+      if (keyDownMatch(event, [keys.Escape, keys.Tab])) {
         event.stopPropagation();
 
         _this._handleUserInputOpenClose(event, {
@@ -392,6 +392,7 @@ var Tooltip = /*#__PURE__*/function (_Component) {
         className: "".concat(prefix, "--tooltip__caret")
       }), /*#__PURE__*/React.createElement("div", {
         className: "".concat(prefix, "--tooltip__content"),
+        "aria-labelledby": this._tooltipId,
         role: "dialog"
       }, children))));
     }
