@@ -18,12 +18,11 @@ function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) r
  * This source code is licensed under the Apache-2.0 license found in the
  * LICENSE file in the root directory of this source tree.
  */
-import { settings } from 'carbon-components';
 import cx from 'classnames';
 import React from 'react';
 import PropTypes from 'prop-types';
 import Link, { LinkPropTypes } from './Link';
-var selectorPrefix = settings.prefix;
+import { usePrefix } from '../../internal/usePrefix';
 
 var HeaderName = function HeaderName(_ref) {
   var children = _ref.children,
@@ -32,6 +31,7 @@ var HeaderName = function HeaderName(_ref) {
       href = _ref.href,
       rest = _objectWithoutProperties(_ref, _excluded);
 
+  var selectorPrefix = usePrefix();
   var className = cx("".concat(selectorPrefix, "--header__name"), customClassName);
   return /*#__PURE__*/React.createElement(Link, _extends({}, rest, {
     className: className,
