@@ -13,12 +13,12 @@ function _defineProperty(obj, key, value) { if (key in obj) { Object.definePrope
  * LICENSE file in the root directory of this source tree.
  */
 import React from 'react';
-import { settings } from 'carbon-components';
 import cx from 'classnames';
 import PropTypes from 'prop-types';
 import { AriaLabelPropType } from '../../prop-types/AriaPropTypes';
-var prefix = settings.prefix;
+import { usePrefix } from '../../internal/usePrefix';
 var Switcher = /*#__PURE__*/React.forwardRef(function Switcher(props, ref) {
+  var prefix = usePrefix();
   var ariaLabel = props['aria-label'],
       ariaLabelledBy = props['aria-labelledby'],
       customClassName = props.className,
@@ -33,6 +33,7 @@ var Switcher = /*#__PURE__*/React.forwardRef(function Switcher(props, ref) {
     className: className
   }, accessibilityLabel), children);
 });
+Switcher.displayName = 'Switcher';
 Switcher.propTypes = _objectSpread(_objectSpread({}, AriaLabelPropType), {}, {
   /**
    * expects to receive <SwitcherItem />
