@@ -8,8 +8,6 @@ var _Switch = _interopRequireDefault(require("../Switch"));
 
 var _enzyme = require("enzyme");
 
-var _carbonComponents = require("carbon-components");
-
 function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }
 
 /**
@@ -18,7 +16,6 @@ function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { de
  * This source code is licensed under the Apache-2.0 license found in the
  * LICENSE file in the root directory of this source tree.
  */
-var prefix = _carbonComponents.settings.prefix;
 describe('ContentSwitcher', function () {
   describe('component initial rendering', function () {
     var wrapper = (0, _enzyme.shallow)( /*#__PURE__*/_react.default.createElement(_ContentSwitcher.default, {
@@ -32,9 +29,6 @@ describe('ContentSwitcher', function () {
       text: "two"
     })));
     var children = wrapper.find(_Switch.default);
-    it('should have the correct class', function () {
-      expect(wrapper.hasClass("".concat(prefix, "--content-switcher"))).toEqual(true);
-    });
     it('should render children as expected', function () {
       expect(children.length).toEqual(2);
     });
