@@ -10,8 +10,6 @@ var _carbonComponents = require("carbon-components");
 
 var _react2 = require("@testing-library/react");
 
-require("@testing-library/jest-dom");
-
 var _userEvent = _interopRequireDefault(require("@testing-library/user-event"));
 
 var _windowOrGlobal = require("window-or-global");
@@ -110,7 +108,7 @@ var prefix = _carbonComponents.settings.prefix;
     })));
   });
   (0, _windowOrGlobal.describe)('keyboard support', function () {
-    it('should recieve keyboard focus', function () {
+    it('should receive keyboard focus', function () {
       (0, _react2.render)( /*#__PURE__*/_react.default.createElement(_Link.default, {
         href: "/",
         className: "some-class"
