@@ -67,12 +67,12 @@ describe('NotificationTextDetails', function () {
   describe('Renders as expected', function () {
     var wrapper = (0, _enzyme.shallow)( /*#__PURE__*/_react.default.createElement(_Notification.NotificationTextDetails, null));
     describe('When notificationType equals "toast"', function () {
-      it('div shoudld have correct className by default', function () {
+      it('div should have correct className by default', function () {
         expect(wrapper.hasClass("".concat(prefix, "--toast-notification__details"))).toBe(true);
       });
     });
     describe('When notificationType equals "inline"', function () {
-      it('div shoudld have correct className', function () {
+      it('div should have correct className', function () {
         wrapper.setProps({
           notificationType: 'inline'
         });
