@@ -165,21 +165,7 @@ describe('OverflowMenu', function () {
       }); // Enzyme doesn't seem to allow state() in a forwardRef-wrapped class component
 
       expect(rootWrapper.find('OverflowMenu').instance().state.open).toEqual(true);
-    }); // Removed until a better solution appears
-    //
-    // it('should be hidden when it loses focus', () => {
-    //   const rootWrapper = mount(
-    //     <OverflowMenu className="extra-class">
-    //       <div className="test-child"></div>
-    //       <div className="test-child"></div>
-    //     </OverflowMenu>
-    //   );
-    //   const menu = rootWrapper.childAt(0);
-    //   rootWrapper.setState({ open: true });
-    //   menu.simulate('blur');
-    //   expect(rootWrapper.state().open).toEqual(false);
-    // });
-
+    });
     it('should be in a closed state after handleOutsideClick() is invoked', function () {
       var rootWrapper = (0, _enzyme.mount)( /*#__PURE__*/_react.default.createElement(_OverflowMenu.default, null)); // Enzyme doesn't seem to allow state() in a forwardRef-wrapped class component
 
