@@ -78,7 +78,7 @@ describe('Switch', function () {
       buttonWrapper.simulate('click', {
         preventDefault: function preventDefault() {}
       });
-      expect(buttonOnClick).toBeCalledWith({
+      expect(buttonOnClick).toHaveBeenCalledWith({
         index: index,
         name: name,
         text: text
@@ -88,7 +88,7 @@ describe('Switch', function () {
       linkWrapper.simulate('click', {
         preventDefault: function preventDefault() {}
       });
-      expect(buttonOnClick).toBeCalledWith({
+      expect(buttonOnClick).toHaveBeenCalledWith({
         index: index,
         name: name,
         text: text
