@@ -35,7 +35,7 @@ describe('TileGroup', function () {
         wrapper.setProps({
           className: 'extra-class'
         });
-        expect(div.hasClass('extra-class'));
+        expect(wrapper.first('div').hasClass('extra-class')).toBe(true);
       });
       it('sets disabled attribute if disabled prop is set', function () {
         wrapper.setProps({
@@ -100,7 +100,7 @@ describe('TileGroup', function () {
     it('should invoke onChange with correct arguments', function () {
       var _expect;
 
-      (_expect = expect(onChange)).toBeCalledWith.apply(_expect, args);
+      (_expect = expect(onChange)).toHaveBeenCalledWith.apply(_expect, args);
     });
     it('calling onChange with same args should not call onChange prop', function () {
       var _firstRadio$props2;
